Version 0.3 — Version 0.11.0.dev0

# Version 0.3

February 22, 2018

## Changelog

### Testing

- Pytest is used instead of nosetests. #321 by Joan Massich.

### Documentation

- Added a User Guide and extended some examples. #295 by Guillaume Lemaitre.

### Bug fixes

- Fixed a bug in `utils.check_ratio` such that an error is raised when the number of samples required is negative. #312 by Guillaume Lemaitre.

- Fixed a bug in `under_sampling.NearMiss` version 3. The indices returned were wrong. #312 by Guillaume Lemaitre.

- Fixed bug for `ensemble.BalanceCascade` and `combine.SMOTEENN` and `SMOTETomek`. #295 by Guillaume Lemaitre.

- Fixed bug for `check_ratio` to be able to pass arguments when `ratio` is a callable. #307 by Guillaume Lemaitre.

### New features

- Turn off steps in `pipeline.Pipeline` using the `None` object. By Christos Aridas.

- Add a fetching function `datasets.fetch_datasets` in order to get some imbalanced datasets useful for benchmarking. #249 by Guillaume Lemaitre.

### Enhancement

- All samplers accepts sparse matrices with defaulting on CSR type. #316 by Guillaume Lemaitre.

- `datasets.make_imbalance` take a ratio similarly to other samplers. It supports multiclass. #312 by Guillaume Lemaitre.

- All the unit tests have been factorized and a `utils.check_estimators` has been derived from scikit-learn. By Guillaume Lemaitre.

- Script for automatic build of conda packages and uploading. #242 by Guillaume Lemaitre

- Remove seaborn dependence and improve the examples. #264 by Guillaume Lemaitre.

- adapt all classes to multi-class resampling. #290 by Guillaume Lemaitre

### API changes summary

- `__init__` has been removed from the `base.SamplerMixin` to create a real mixin class. #242 by Guillaume Lemaitre.

- creation of a module `exceptions` to handle consistant raising of errors. #242 by Guillaume Lemaitre.

- creation of a module `utils.validation` to make checking of recurrent patterns. #242 by Guillaume Lemaitre.

- move the under-sampling methods in `prototype_selection` and `prototype_generation` submodule to make a clearer dinstinction. #277 by Guillaume Lemaitre.

- change `ratio` such that it can adapt to multiple class problems. #290 by Guillaume Lemaitre.

### Deprecation

- Deprecation of the use of `min_c_` in `datasets.make_imbalance`. #312 by Guillaume Lemaitre

- Deprecation of the use of float in `datasets.make_imbalance` for the ratio parameter. #290 by Guillaume Lemaitre.

- deprecate the use of float as ratio in favor of dictionary, string, or callable. #290 by Guillaume Lemaitre.